@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclExtdInt.h,v 5.0 1995/07/25 05:42:46 markd Rel $
+ * $Id: tclExtdInt.h,v 5.3 1995/09/05 07:55:47 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -23,37 +23,22 @@
 #include "tclXconf.h"
 #include "tclInt.h"
 
+#if (TCL_MINOR_VERSION < 5)
+/*
+ * Hack for dual support of TclX 7.4 & TclX 7.5.
+ */
+#  define TCLX_7_4
+#  define TclOpenFile OpenFile
+#  define Tcl_AsyncReady() (tcl_AsyncReady)
+#  define TCL_VARARGS(type, name) ()
+#  define TCL_VARARGS_DEF(type, name) (va_alist)
+#  define TCL_VARARGS_START(type, name, list) \
+	(va_start(list), va_arg(list, type))
+#endif
+
+
 #include <sys/param.h>
 
-/*
- * Use the real functions, not the Tcl interface that hides signals.
- */
-#undef open
-#undef read
-#undef waitpid
-#undef write
-
-/*
- * If tclUnix.h has already included time.h, don't include it again, some
- * systems don't #ifdef inside of the file.
- */
-#ifndef NO_SYS_TIME_H
-#    include <time.h>
-#endif
-
-#include <sys/times.h>
-
-/*
- * Make sure CLK_TCK is defined.
- */
-#ifndef CLK_TCK
-#    ifdef HZ
-#        define CLK_TCK HZ
-#    else
-#        define CLK_TCK 60
-#    endif
-#endif
-
 #include <math.h>
 
 #ifdef NO_VALUES_H
@@ -69,10 +54,52 @@
 #include <grp.h>
 
 /*
- * Included the tcl file tclUnix.h after other system files, as it checks
+ * Included the tcl file tclPort.h after other system files, as it checks
  * if certain things are defined.
  */
+#ifdef TCLX_7_4
 #include "tclPort.h"
+#else
+#include "tclUnixPort.h"
+#endif
+
+/*
+ * Use the real functions, not the Tcl interface that hides signals.
+ */
+#undef open
+#undef read
+#undef waitpid
+#undef write
+
+/*
+ * Define O_ACCMODE if <fcntl.h> does not define it.
+ */
+#ifndef O_ACCMODE
+#    define O_ACCMODE  (O_RDONLY|O_WRONLY|O_RDWR)
+#endif
+
+/*
+ * If tclPort.h has already included time.h, don't include it again, some
+ * systems don't #ifdef inside of the file.  Also, on some of these systems,
+ * time.h is included by sys/time.h, so don't include it again if that is the
+ * case.
+ */
+#if !defined (NO_SYS_TIME_H) && defined(TIME_WITH_SYS_TIME)
+#    include <time.h>
+#endif
+
+#include <sys/times.h>
+
+/*
+ * Make sure CLK_TCK is defined.
+ */
+#ifndef CLK_TCK
+#    ifdef HZ
+#        define CLK_TCK HZ
+#    else
+#        define CLK_TCK 60
+#    endif
+#endif
 
 /*
  * These should be take from an include file, but it got to be such a mess
@@ -84,7 +111,7 @@ struct tm *localtime ();
 
 /*
  * Get ranges of integers and longs.
- *  If no MAXLONG, assume sizeof (long) == sizeof (int).
+ * If no MAXLONG, assume sizeof (long) == sizeof (int).
  */
 
 #ifndef MAXINT
@@ -181,26 +208,6 @@ extern char *tclXWrongArgs;
   (strcpy (ckalloc (strlen (sourceStr) + 1), sourceStr))
 
 
-/*
- * Macros to get the stdin, stdout and stderr pointers out of the interpreter
- * when error status is not desired.
- */
-#define TCL_STDIN \
-    (((tclNumFiles < 1) || (tclOpenFiles [0] == NULL)) ? \
-     stdin : tclOpenFiles [0]->f)
-
-#define TCL_STDOUT \
-    (((tclNumFiles < 2) || (tclOpenFiles [1] == NULL)) ? \
-     stdout : \
-      ((tclOpenFiles [1]->f2 != NULL) ? tclOpenFiles [1]->f2 : \
-       tclOpenFiles [1]->f))
-
-#define TCL_STDERR \
-    (((tclNumFiles < 3) || (tclOpenFiles [2] == NULL)) ? \
-     stderr : \
-      ((tclOpenFiles [2]->f2 != NULL) ? tclOpenFiles [2]->f2 : \
-       tclOpenFiles [2]->f))
-
 
 /*
  * Prototypes for utility procedures.
@@ -228,7 +235,11 @@ TclX_Eval _ANSI_ARGS_((Tcl_Interp  *interp,
                        char        *cmd));
 
 extern int
-TclX_VarEval ();
+TclX_VarEval _ANSI_ARGS_(TCL_VARARGS(Tcl_Interp *, arg1));
+
+FILE *
+TclX_Stdfile _ANSI_ARGS_((Tcl_Interp  *interp,
+                          FILE        *stdfile));
 
 extern int
 Tcl_GetDate _ANSI_ARGS_((char   *p,
@@ -236,9 +247,13 @@ Tcl_GetDate _ANSI_ARGS_((char   *p,
                          long    zone,
                          time_t *timePtr));
 
-extern OpenFile *
-Tcl_GetOpenFileStruct _ANSI_ARGS_((Tcl_Interp *interp,
-                                   char       *handle));
+TclOpenFile *
+TclX_FNumToFileStruct _ANSI_ARGS_((Tcl_Interp  *interp,
+                                   int          fnum));
+
+extern TclOpenFile *
+TclX_GetOpenFileStruct _ANSI_ARGS_((Tcl_Interp *interp,
+                                    char       *handle));
 
 extern int
 Tcl_GetTime _ANSI_ARGS_((Tcl_Interp *interp,
