@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclExtend.h,v 4.8 1995/04/02 16:48:16 markd Exp $
+ * $Id: tclExtend.h,v 5.1 1995/09/30 18:06:33 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -27,7 +27,7 @@
  * version to form the actual extended Tcl version.
  */
 
-#define TCL_EXTD_VERSION_SUFFIX "a-b3"   /* 7.3a-b3 */
+#define TCL_EXTD_VERSION_SUFFIX "a-a1"   /* 7.5a */
 
 typedef void *void_pt;
 
@@ -45,10 +45,9 @@ extern char *tclAppVersion;      /* Version number of the application       */
 extern int   tclAppPatchlevel;   /* Patchlevel of the application           */
 
 /*
- * Used to override the library and library environment variable used to
- * find the TclX startup file and runtime library.  Also the init file name,
- * which is either library relative or absolute.  The values of these
- * fields must be changed before TclX_Init or TclXLib_Init is called.
+ * Used to override the init file name, which is either library relative or
+ * absolute.  The value fields must be changed before TclX_Init or
+ * TclXLib_Init is called.  To change the library location,
  */
 extern char *tclX_library;     /* Library directory to use.        */
 extern char *tclX_libraryEnv;  /* Override environment variable.   */
@@ -83,8 +82,9 @@ extern int tclDeleteInterpAtEnd;
  * Exported TclX initialization functions.
  */
 EXTERN void
-TclX_Main _ANSI_ARGS_((int    argc,
-                       char **argv));
+TclX_Main _ANSI_ARGS_((int              argc,
+                       char           **argv,
+                       Tcl_AppInitProc *appInitProc));
 
 EXTERN int
 TclX_Init _ANSI_ARGS_((Tcl_Interp *interp));
@@ -126,6 +126,9 @@ Tcl_GetLong _ANSI_ARGS_((Tcl_Interp  *interp,
                          CONST char *string,
                          long        *longPtr));
 
+EXTERN int
+Tcl_GetTimeZone _ANSI_ARGS_((long  currentTime));
+
 EXTERN int 
 Tcl_GetUnsigned _ANSI_ARGS_((Tcl_Interp  *interp,
                              CONST char *string,
@@ -218,8 +221,7 @@ Tcl_HandleXlate _ANSI_ARGS_((Tcl_Interp  *interp,
                              CONST  char *handle));
 
 /*
- * Tk with TclX initialization.  These should really be in there own
- * include file.
+ * Tk with TclX initialization.
  *
  * The variables are Used to override the library and library environment
  * variable used to find the TkX startup file and runtime library.  The values
@@ -228,11 +230,12 @@ Tcl_HandleXlate _ANSI_ARGS_((Tcl_Interp  *interp,
 extern char *tkX_library;
 extern char *tkX_libraryEnv;
 
-EXTERN void
-TkX_Main _ANSI_ARGS_((int    argc,
-                      char **argv));
-
 EXTERN int
 TkX_Init _ANSI_ARGS_((Tcl_Interp  *interp));
 
+EXTERN void
+TkX_Main _ANSI_ARGS_((int               argc,
+                      char            **argv,
+                      Tcl_AppInitProc  *appInitProc));
+
 #endif
