@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXdebug.c,v 4.2 1995/01/01 19:49:24 markd Exp $
+ * $Id: tclXdebug.c,v 5.1 1995/09/05 07:55:47 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -27,10 +27,12 @@
 typedef struct traceInfo_t {
     Tcl_Interp *interp;
     Tcl_Trace   traceHolder;
+    int         inTrace;
     int         noEval;
     int         noTruncate;
     int         procCalls;
     int         depth;
+    char       *callback;
     FILE       *filePtr;          /* File to output trace to. */
     } traceInfo_t, *traceInfo_pt;
 
@@ -38,6 +40,10 @@ typedef struct traceInfo_t {
  * Prototypes of internal functions.
  */
 static void
+TraceDelete _ANSI_ARGS_((Tcl_Interp   *interp,
+                         traceInfo_pt  infoPtr));
+
+static void
 PrintStr _ANSI_ARGS_((FILE *filePtr,
                       char *string,
                       int   numChars));
@@ -48,12 +54,20 @@ PrintArg _ANSI_ARGS_((FILE *filePtr,
                       int   noTruncate));
 
 static void
-TraceCode  _ANSI_ARGS_((traceInfo_pt traceInfoPtr,
+TraceCode  _ANSI_ARGS_((traceInfo_pt infoPtr,
                         int          level,
                         char        *command,
                         int          argc,
                         char       **argv));
 
+static void
+TraceCallBack _ANSI_ARGS_((Tcl_Interp   *interp,
+                           traceInfo_pt  infoPtr,
+                           int           level,
+                           char         *command,
+                           int           argc,
+                           char        **argv));
+
 static void
 CmdTraceRoutine _ANSI_ARGS_((ClientData    clientData,
                              Tcl_Interp   *interp,
@@ -68,6 +82,29 @@ static void
 DebugCleanUp _ANSI_ARGS_((ClientData  clientData,
                           Tcl_Interp *interp));
 
+
+/*
+ *-----------------------------------------------------------------------------
+ * TraceDelete --
+ *
+ *   Delete the trace if active, reseting the structure.
+ *-----------------------------------------------------------------------------
+ */
+static void
+TraceDelete (interp, infoPtr)
+    Tcl_Interp   *interp;
+    traceInfo_pt  infoPtr;
+{
+    if (infoPtr->traceHolder != NULL) {
+        Tcl_DeleteTrace (interp, infoPtr->traceHolder);
+        infoPtr->depth = 0;
+        infoPtr->traceHolder = NULL;
+        if (infoPtr->callback != NULL) {
+            ckfree (infoPtr->callback);
+            infoPtr->callback = NULL;
+        }
+    }
+}
 
 /*
  *-----------------------------------------------------------------------------
@@ -143,8 +180,8 @@ PrintArg (filePtr, argStr, noTruncate)
  *-----------------------------------------------------------------------------
  */
 static void
-TraceCode (traceInfoPtr, level, command, argc, argv)
-    traceInfo_pt traceInfoPtr;
+TraceCode (infoPtr, level, command, argc, argv)
+    traceInfo_pt infoPtr;
     int          level;
     char        *command;
     int          argc;
@@ -152,33 +189,140 @@ TraceCode (traceInfoPtr, level, command, argc, argv)
 {
     int idx, cmdLen, printLen;
 
-    fprintf (traceInfoPtr->filePtr, "%2d:", level);
+    fprintf (infoPtr->filePtr, "%2d:", level);
 
     if (level > 20)
         level = 20;
     for (idx = 0; idx < level; idx++) 
-        fprintf (traceInfoPtr->filePtr, "  ");
+        fprintf (infoPtr->filePtr, "  ");
 
-    if (traceInfoPtr->noEval) {
+    if (infoPtr->noEval) {
         cmdLen = printLen = strlen (command);
-        if ((!traceInfoPtr->noTruncate) && (printLen > CMD_TRUNCATE_SIZE))
+        if ((!infoPtr->noTruncate) && (printLen > CMD_TRUNCATE_SIZE))
             printLen = CMD_TRUNCATE_SIZE;
 
-        PrintStr (traceInfoPtr->filePtr, command, printLen);
+        PrintStr (infoPtr->filePtr, command, printLen);
       } else {
           for (idx = 0; idx < argc; idx++) {
               if (idx > 0)
-                  putc (' ', traceInfoPtr->filePtr);
-              PrintArg (traceInfoPtr->filePtr, argv[idx], 
-                        traceInfoPtr->noTruncate);
+                  putc (' ', infoPtr->filePtr);
+              PrintArg (infoPtr->filePtr, argv[idx], 
+                        infoPtr->noTruncate);
           }
     }
 
-    putc ('\n', traceInfoPtr->filePtr);
-    fflush (traceInfoPtr->filePtr);
+    putc ('\n', infoPtr->filePtr);
+    fflush (infoPtr->filePtr);
   
 }
 
+/*
+ *-----------------------------------------------------------------------------
+ * TraceCallBack --
+ *
+ *   Build and call a callback for the command that was just executed. The
+ * following arguments are appended to the command:
+ *   1) command - A string containing the text of the command, before any
+ *      argument substitution.
+ *   2) argv - A list of the final argument information that will be passed to
+ *     the command after command, variable, and backslash substitution.
+ *   3) evalLevel - The Tcl_Eval level.
+ *   4) procLevel - The procedure level.
+ * The code should allow for additional substitution of arguments in future
+ * versions (such as a procedure with args as the last argument).  The value
+ * of result, errorInfo and errorCode are preserved.  All other state must be
+ * preserved by the procedure.  A error will result in information being dumped
+ * to stderr and the trace deleted.
+ *-----------------------------------------------------------------------------
+ */
+static void
+TraceCallBack (interp, infoPtr, level, command, argc, argv)
+    Tcl_Interp   *interp;
+    traceInfo_pt  infoPtr;
+    int           level;
+    char         *command;
+    int           argc;
+    char        **argv;
+{
+    Interp       *iPtr = (Interp *) interp;
+    Tcl_DString   callback, resultBuf, errorInfoBuf, errorCodeBuf;
+    char         *cmdList, *errorInfo, *errorCode;
+    char          numBuf [32];
+
+    Tcl_DStringInit (&callback);
+    Tcl_DStringInit (&resultBuf);
+    Tcl_DStringInit (&errorInfoBuf);
+    Tcl_DStringInit (&errorCodeBuf);
+
+    /*
+     * Build the command to evaluate.
+     */
+    Tcl_DStringAppend (&callback, infoPtr->callback, -1);
+
+    Tcl_DStringStartSublist (&callback);
+    Tcl_DStringAppendElement (&callback, command);
+    Tcl_DStringEndSublist (&callback);
+
+    Tcl_DStringStartSublist (&callback);
+    cmdList = Tcl_Merge (argc, argv);
+    Tcl_DStringAppendElement (&callback, cmdList);
+    ckfree (cmdList);
+    Tcl_DStringEndSublist (&callback);
+
+    sprintf (numBuf, "%d", level);
+    Tcl_DStringAppendElement (&callback, numBuf);
+
+    sprintf (numBuf, "%d",  ((iPtr->varFramePtr == NULL) ? 0 : 
+             iPtr->varFramePtr->level));
+    Tcl_DStringAppendElement (&callback, numBuf);
+
+    /*
+     * Save errorInfo and errorCode.
+     */
+    Tcl_DStringGetResult (interp, &resultBuf);
+    errorInfo = Tcl_GetVar (interp, "errorInfo", TCL_GLOBAL_ONLY);
+    if (errorInfo != NULL)
+        Tcl_DStringAppend (&errorInfoBuf, errorInfo, -1);
+    errorCode = Tcl_GetVar (interp, "errorCode", TCL_GLOBAL_ONLY);
+    if (errorCode != NULL)
+        Tcl_DStringAppend (&errorCodeBuf, errorCode, -1);
+
+    /*
+     * Evaluate the command.  If an error occurs, dump something to stderr
+     * and delete the trace.  There is no way to return a error at this
+     * point.
+     */
+    if (Tcl_Eval (interp, Tcl_DStringValue (&callback)) == TCL_ERROR) {
+        FILE *stderrPtr = TclX_Stdfile (interp, stderr);
+
+        Tcl_AddErrorInfo (interp, "\n    (\"cmdtrace\" callback command)");
+
+        fprintf (stderrPtr,
+                 "cmdtrace callback command error: errorCode = %s\n",
+                 Tcl_GetVar (interp, "errorCode", TCL_GLOBAL_ONLY));
+        fprintf (stderrPtr, "%s\n",
+                 Tcl_GetVar (interp, "errorInfo", TCL_GLOBAL_ONLY));
+        fflush (stderrPtr);
+        TraceDelete (interp, infoPtr);
+    }
+
+    /*
+     * Restore errorInfo and errorCode.
+     */
+    if (errorInfo != NULL)
+        Tcl_SetVar (interp, "errorInfo", Tcl_DStringValue (&errorInfoBuf),
+                    TCL_GLOBAL_ONLY);
+    if (errorCode != NULL)
+        Tcl_SetVar (interp, "errorCode", Tcl_DStringValue (&errorCodeBuf),
+                    TCL_GLOBAL_ONLY);
+    Tcl_DStringResult (interp, &resultBuf);
+
+    Tcl_DStringFree (&callback);
+    Tcl_DStringFree (&resultBuf);
+    Tcl_DStringFree (&errorInfoBuf);
+    Tcl_DStringFree (&errorCodeBuf);
+}
+
 /*
  *-----------------------------------------------------------------------------
  * CmdTraceRoutine --
@@ -199,18 +343,31 @@ CmdTraceRoutine (clientData, interp, level, command, cmdProc, cmdClientData,
     char        **argv;
 {
     Interp       *iPtr = (Interp *) interp;
-    traceInfo_pt  traceInfoPtr = (traceInfo_pt) clientData;
+    traceInfo_pt  infoPtr = (traceInfo_pt) clientData;
     int           procLevel;
 
-    if (!traceInfoPtr->procCalls) {
-        TraceCode (traceInfoPtr, level, command, argc, argv);
-    } else {
+    if (infoPtr->inTrace)
+        return;
+    infoPtr->inTrace = TRUE;
+
+    if (infoPtr->procCalls) {
         if (TclFindProc (iPtr, argv [0]) != NULL) {
-            procLevel = (iPtr->varFramePtr == NULL) ? 0 : 
-                        iPtr->varFramePtr->level;
-            TraceCode (traceInfoPtr, procLevel, command, argc, argv);
+            if (infoPtr->callback != NULL) {
+                TraceCallBack (interp, infoPtr, level, command, argc, argv);
+            } else {
+                procLevel = (iPtr->varFramePtr == NULL) ? 0 : 
+                    iPtr->varFramePtr->level;
+                TraceCode (infoPtr, procLevel, command, argc, argv);
+            }
+        }
+    } else {
+        if (infoPtr->callback != NULL) {
+            TraceCallBack (interp, infoPtr, level, command, argc, argv);
+        } else {
+            TraceCode (infoPtr, level, command, argc, argv);
         }
     }
+    infoPtr->inTrace = FALSE;
 }
 
 /*
@@ -218,7 +375,7 @@ CmdTraceRoutine (clientData, interp, level, command, cmdProc, cmdClientData,
  * Tcl_CmdtraceCmd --
  *
  * Implements the TCL trace command:
- *     cmdtrace level|on ?noeval? ?notruncate? ?procs? ?fileid?
+ *     cmdtrace level|on ?noeval? ?notruncate? ?procs? ?fileid? ?command cmd?
  *     cmdtrace off
  *     cmdtrace depth
  *-----------------------------------------------------------------------------
@@ -232,7 +389,7 @@ Tcl_CmdtraceCmd (clientData, interp, argc, argv)
 {
     traceInfo_pt  infoPtr = (traceInfo_pt) clientData;
     int           idx;
-    char         *fileHandle;
+    char         *fileHandle, *callback;
 
     if (argc < 2)
         goto argumentError;
@@ -250,11 +407,7 @@ Tcl_CmdtraceCmd (clientData, interp, argc, argv)
     /*
      * If a trace is in progress, delete it now.
      */
-    if (infoPtr->traceHolder != NULL) {
-        Tcl_DeleteTrace(interp, infoPtr->traceHolder);
-        infoPtr->depth = 0;
-        infoPtr->traceHolder = NULL;
-    }
+    TraceDelete (interp, infoPtr);
 
     /*
      * Handle off sub-command.
@@ -270,6 +423,7 @@ Tcl_CmdtraceCmd (clientData, interp, argc, argv)
     infoPtr->procCalls  = FALSE;
     infoPtr->filePtr    = NULL;
     fileHandle          = NULL;
+    callback            = NULL;
 
     for (idx = 2; idx < argc; idx++) {
         if (STREQU (argv[idx], "notruncate")) {
@@ -294,9 +448,21 @@ Tcl_CmdtraceCmd (clientData, interp, argc, argv)
                 STRNEQU (argv [idx], "file", 4)) {
             if (fileHandle != NULL)
                 goto argumentError;
+            if (callback != NULL)
+                goto mixCommandAndFile;
             fileHandle = argv [idx];
             continue;
         }
+        if (STREQU (argv [idx], "command")) {
+            if (callback != NULL)
+                goto argumentError;
+            if (fileHandle != NULL)
+                goto mixCommandAndFile;
+            if (idx == argc - 1)
+                goto missingCommand;
+            callback = argv [++idx];
+            continue;
+        }
         goto invalidOption;
     }
 
@@ -307,29 +473,41 @@ Tcl_CmdtraceCmd (clientData, interp, argc, argv)
             return TCL_ERROR;
     }
 
-    if (fileHandle == NULL)
-        fileHandle = "stdout";
-    if (Tcl_GetOpenFile (interp, fileHandle, 
-                         TRUE,   /* Write access */
-                         TRUE,   /* Check access */
-                         &infoPtr->filePtr) != TCL_OK)
-        return TCL_ERROR;
-    
+    if (callback != NULL) {
+        infoPtr->callback = ckstrdup (callback);
+    } else {
+        if (fileHandle == NULL)
+            fileHandle = "stdout";
+        if (Tcl_GetOpenFile (interp, fileHandle, 
+                             TRUE, TRUE,  /* Write access, checked */
+                             &infoPtr->filePtr) != TCL_OK)
+            return TCL_ERROR;
+    }
     infoPtr->traceHolder = Tcl_CreateTrace (interp, infoPtr->depth,
                                             CmdTraceRoutine,
                                             (ClientData) infoPtr);
     return TCL_OK;
 
-argumentError:
+  argumentError:
     Tcl_AppendResult (interp, tclXWrongArgs, argv [0], 
                       " level | on ?noeval? ?notruncate? ?procs?",
-                      "?fileid? | off | depth", (char *) NULL);
+                      "?fileid? ?command cmd? | off | depth", (char *) NULL);
     return TCL_ERROR;
 
-invalidOption:
+  missingCommand:
+    Tcl_AppendResult (interp, "command option requires an argument",
+                      (char *) NULL);
+    return TCL_ERROR;
+
+  mixCommandAndFile:
+    Tcl_AppendResult (interp, "can not specify both the command option and ",
+                      "a file handle", (char *) NULL);
+    return TCL_ERROR;
+
+  invalidOption:
     Tcl_AppendResult (interp, "invalid option: expected ",
                       "one of \"noeval\", \"notruncate\", \"procs\", ",
-                      "or a file id", (char *) NULL);
+                      "\"command\", or a file id", (char *) NULL);
     return TCL_ERROR;
 }
 
@@ -347,8 +525,7 @@ DebugCleanUp (clientData, interp)
 {
     traceInfo_pt infoPtr = (traceInfo_pt) clientData;
 
-    if (infoPtr->traceHolder != NULL)
-        Tcl_DeleteTrace (infoPtr->interp, infoPtr->traceHolder);
+    TraceDelete (interp, infoPtr);
     ckfree ((char *) infoPtr);
 }
 
@@ -369,10 +546,13 @@ Tcl_InitDebug (interp)
 
     infoPtr->interp      = interp;
     infoPtr->traceHolder = NULL;
+    infoPtr->inTrace     = FALSE;
     infoPtr->noEval      = FALSE;
     infoPtr->noTruncate  = FALSE;
     infoPtr->procCalls   = FALSE;
     infoPtr->depth       = 0;
+    infoPtr->callback    = NULL;
+    infoPtr->filePtr     = NULL;
 
     Tcl_CallWhenDeleted (interp, DebugCleanUp, (ClientData) infoPtr);
 
