@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXinit.c,v 5.0 1995/07/25 05:59:07 markd Rel $
+ * $Id: tclXinit.c,v 5.3 1995/09/11 05:00:58 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -58,8 +58,8 @@ TclX_ErrorExit (interp, exitCode)
     char  numBuf [32];
     FILE *stdoutPtr, *stderrPtr;
 
-    stdoutPtr = TCL_STDOUT;
-    stderrPtr = TCL_STDERR;
+    stdoutPtr = TclX_Stdfile (interp, stdout);
+    stderrPtr = TclX_Stdfile (interp, stderr);
 
     fflush (stdoutPtr);
 
@@ -266,22 +266,25 @@ TclX_EvalRCFile (interp)
     Tcl_Interp  *interp;
 {
     Tcl_DString  buffer;
-    char        *fullName;
+    char        *path;
 
-    if (tcl_RcFileName != NULL) {
-        fullName = Tcl_TildeSubst (interp, tcl_RcFileName, &buffer);
-        if (fullName == NULL)
-            TclX_ErrorExit (interp, 1);
+    path = Tcl_GetVar (interp, "tcl_rcFileName", TCL_GLOBAL_ONLY);
+    if (path == NULL)
+        return;
+
+    Tcl_DStringInit (&buffer);
+
+    path = Tcl_TildeSubst (interp, path, &buffer);
+    if (path == NULL)
+        TclX_ErrorExit (interp, 1);
         
-        if (access(fullName, R_OK) == 0) {
-            if (TclX_Eval (interp,
-                           TCLX_EVAL_GLOBAL | TCLX_EVAL_FILE |
-                           TCLX_EVAL_ERR_HANDLER,
-                           fullName) == TCL_ERROR) {
-                Tcl_DStringFree(&buffer);
-                TclX_ErrorExit (interp, 1);
-            }
+    if (access (path, R_OK) == 0) {
+        if (TclX_Eval (interp,
+                       TCLX_EVAL_GLOBAL | TCLX_EVAL_FILE |
+                       TCLX_EVAL_ERR_HANDLER,
+                       path) == TCL_ERROR) {
+            TclX_ErrorExit (interp, 1);
         }
-	Tcl_DStringFree(&buffer);
     }
+    Tcl_DStringFree(&buffer);
 }
