@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXlib.c,v 4.5 1995/01/16 07:39:53 markd Exp $
+ * $Id: tclXlib.c,v 5.0 1995/07/25 05:42:41 markd Rel $
  *-----------------------------------------------------------------------------
  */
 
@@ -49,7 +49,7 @@ static char *AUTO_PKG_INDEX = "auto_pkg_index";
  * This is a global rather than a local so it will work with K&R compilers.
  * Its writable so it works with gcc.
  */
-static char loadOusterCmd [] = "source [info library]/loadouster.tcl";
+static char loadOusterCmd [] = "source $tclx_library/loadouster.tcl";
 
 
 /*
@@ -133,6 +133,12 @@ RemoveInProgress _ANSI_ARGS_((Tcl_Interp  *interp,
                               libInfo_t   *infoPtr,
                               char        *command));
 
+static int
+LoadChangedPathPackageIndexes _ANSI_ARGS_((Tcl_Interp  *interp,
+                                           libInfo_t   *infoPtr,
+                                           char        *oldPath,
+                                           char        *path));
+
 static int
 LoadAutoPath _ANSI_ARGS_((Tcl_Interp  *interp,
                           libInfo_t   *infoPtr));
@@ -609,15 +615,13 @@ ProcessIndexFile (interp, tlibFilePath, tndxFilePath)
  * BuildPackageIndex --
  *
  * Call the "buildpackageindex" Tcl procedure to rebuild a package index.
- * This is found with the [info library] command.
+ * This is found in the directory pointed to by the $tclx_library variable.
  *
  * Parameters
  *   o interp (I) - A pointer to the interpreter, error returned in result.
  *   o tlibFilePath (I) - Absolute path name to the library file.
  * Returns:
  *   TCL_OK or TCL_ERROR.
- *
- * ????Change name to auto something.
  *-----------------------------------------------------------------------------
  */
 static int
@@ -630,7 +634,7 @@ BuildPackageIndex (interp, tlibFilePath)
 
     Tcl_DStringInit (&command);
 
-    Tcl_DStringAppend (&command, "source [info library]/buildidx.tcl;", -1);
+    Tcl_DStringAppend (&command, "source $tclx_library/buildidx.tcl;", -1);
     Tcl_DStringAppend (&command, "buildpackageindex ", -1);
     Tcl_DStringAppend (&command, tlibFilePath, -1);
 
@@ -720,7 +724,7 @@ LoadPackageIndex (interp, tlibFilePath)
  *   The real work of loading an index is done by a procedure that is defined
  * in a seperate file.  Its not possible to put this file in the standard
  * tcl.tlib as a tclIndex might get loaded before the tcl.tndx file is found
- * on the search path.  The function sources [info library]/loadouster.tcl
+ * on the search path.  The function sources $tclx_library/loadouster.tcl
  * if it has not been loaded before.
  *-----------------------------------------------------------------------------
  */
@@ -1001,12 +1005,70 @@ RemoveInProgress (interp, infoPtr, command)
     Tcl_DeleteHashEntry (entryPtr);
 }
 
+/*
+ *-----------------------------------------------------------------------------
+ * LoadChangedPathPackageIndexes --
+ *
+ *   Determine what part of the path has changed and load the package indexes
+ * just for the appended direcories.
+ *
+ * Parameters
+ *   o interp (I) - A pointer to the interpreter, error returned in result.
+ *   o infoPtr (I) - Interpreter specific library info.
+ *   o oldPath (I) - The previous value of auto_path.
+ *   o path (I) - The current value of auto_path.
+ * Returns:
+ *   TCL_OK or TCL_ERROR
+ *-----------------------------------------------------------------------------
+ */
+static int
+LoadChangedPathPackageIndexes (interp, infoPtr, oldPath, path)
+    Tcl_Interp  *interp;
+    libInfo_t   *infoPtr;
+    char        *oldPath;
+    char        *path;
+{
+    char   *changedPath = NULL;
+    int     pathArgc, oldPathArgc, idx;
+    char  **pathArgv = NULL, **oldPathArgv = NULL;
+
+    if (Tcl_SplitList (interp, oldPath, &oldPathArgc, &oldPathArgv) != TCL_OK)
+        goto errorExit;
+    if (Tcl_SplitList (interp, path, &pathArgc, &pathArgv) != TCL_OK)
+        goto errorExit;
+
+    for (idx = 0; (idx < oldPathArgc) && (idx < pathArgc); idx++) {
+        if (!STREQU (oldPathArgv [idx], pathArgv [idx]))
+            break;
+    }
+    changedPath = Tcl_Merge (pathArgc - idx, &pathArgv [idx]);
+
+    if (LoadPackageIndexes (interp, infoPtr, changedPath) != TCL_OK)
+        goto errorExit;
+
+    ckfree (changedPath);
+    ckfree ((char *) pathArgv);
+    ckfree ((char *) oldPathArgv);
+    return TCL_OK;
+
+  errorExit:
+    if (changedPath != NULL)
+        ckfree (changedPath);
+    if (pathArgv != NULL)
+        ckfree ((char *) pathArgv);
+    if (oldPathArgv != NULL)
+        ckfree ((char *) oldPathArgv);
+    return TCL_ERROR;
+
+}
+
 /*
  *-----------------------------------------------------------------------------
  * LoadAutoPath --
  *
  *   Load all indexs on the auto_path variable.  If auto_path has not changed
- * since the last time libraries were successfully loaded, this is a no-op.
+ * or has just been appended to, since the last time libraries were
+ * successfully loaded, this is a no-op.
  *
  * Parameters
  *   o interp (I) - A pointer to the interpreter, error returned in result.
@@ -1020,7 +1082,7 @@ LoadAutoPath (interp, infoPtr)
     Tcl_Interp  *interp;
     libInfo_t   *infoPtr;
 {
-    char  *path, *oldPath;
+    char   *path, *oldPath;
 
     path = Tcl_GetVar (interp, AUTO_PATH, TCL_GLOBAL_ONLY);
     if (path == NULL)
@@ -1029,14 +1091,23 @@ LoadAutoPath (interp, infoPtr)
     oldPath = Tcl_GetVar (interp, AUTO_OLDPATH, TCL_GLOBAL_ONLY);
 
     /*
-     * Check if the path has changed.  If it has, load indexes, and
-     * save the path if it succeeds.
+     * Check if the path has not changed at all.
      */
     if ((oldPath != NULL) && STREQU (path, oldPath))
         return TCL_OK;
 
-    if (LoadPackageIndexes (interp, infoPtr, path) != TCL_OK)
-        return TCL_ERROR;
+    /*
+     * If the old path exists, then load only the appended directories.
+     * Otherwise, load the entire path.
+     */
+    if (oldPath != NULL) {
+        if (LoadChangedPathPackageIndexes (interp, infoPtr, oldPath,
+                                           path) != TCL_OK)
+            return TCL_ERROR;
+    } else {
+        if (LoadPackageIndexes (interp, infoPtr, path) != TCL_OK)
+            return TCL_ERROR;
+    }
 
     if (Tcl_SetVar (interp, AUTO_OLDPATH, path,
                     TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
