@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXsignal.c,v 5.0 1995/07/25 05:58:49 markd Rel $
+ * $Id: tclXsignal.c,v 5.1 1995/08/04 05:56:17 markd Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -34,6 +34,13 @@
 #  endif
 #endif
 
+/*
+ * Encore UMAX doesn't define SIG_ERR!.
+ */
+#ifndef SIG_ERR
+#   define SIG_ERR  (void (*)())-1
+#endif
+
 /*
  * Value returned by Tcl_SignalId when an invalid signal is passed in.
  * Pointer is used as a quick check of a valid signal number.
