@@ -33,7 +33,7 @@
 # ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
 # PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 #------------------------------------------------------------------------------
-# $Id: tcllib.tcl,v 4.1 1995/01/01 19:50:01 markd Exp $
+# $Id: tcllib.tcl,v 5.1 1995/08/09 15:06:47 markd Exp $
 #------------------------------------------------------------------------------
 #
 
@@ -149,20 +149,20 @@ proc auto_reset {} {
     catch {unset auto_index}
     catch {unset auto_oldpath}
     # *** TclX ***
-    global auto_pkg_index
+    global auto_pkg_index tclx_library
     catch {unset auto_pkg_index}
-    set auto_index(buildpackageindex) {source [info library]/buildidx.tcl}
+    set auto_index(buildpackageindex) {source $tclx_library/buildidx.tcl}
     return
 }
 
 #------------------------------------------------------------------------------
 # auto_mkindex:
-# Regenerate a tclIndex file from Tcl source files.  Takes two arguments:
+# Regenerate a tclIndex file from Tcl source files.  Takes as argument
 # the name of the directory in which the tclIndex file is to be placed,
-# and a glob pattern to use in that directory to locate all of the relevant
-# files.
+# floowed by any number of glob patterns to use in that directory to
+# locate all of the relevant files.
 
-proc auto_mkindex {dir files} {
+proc auto_mkindex {dir args} {
     global errorCode errorInfo
     set oldDir [pwd]
     cd $dir
@@ -174,7 +174,7 @@ proc auto_mkindex {dir files} {
     append index "# sets an element in the auto_index array, where the\n"
     append index "# element name is the name of a command and the value is\n"
     append index "# a script that loads the command.\n\n"
-    foreach file [glob $files] {
+    foreach file [eval glob $args] {
 	set f ""
 	set error [catch {
 	    set f [open $file]
@@ -189,7 +189,7 @@ proc auto_mkindex {dir files} {
 	if $error {
 	    set code $errorCode
 	    set info $errorInfo
-	    catch [close $f]
+	    catch {close $f}
 	    cd $oldDir
 	    error $msg $info $code
 	}
@@ -199,4 +199,3 @@ proc auto_mkindex {dir files} {
     close $f
     cd $oldDir
 }
-
