@@ -44,7 +44,9 @@
 # tclx_unknown:
 # This implements the slow path of the TclX unknown command.  It must be called
 # directly from the unknown command.  This handles exec-ing of Unix programs
-# and interactive csh style redo.
+# and interactive csh style redo.  The returns a command to evaluate. If an
+# error occured, the command returns is an "error" command to return the
+# appropriate error message.
 
 proc tclx_unknown2 cmd {
     global tcl_interactive auto_noexec
@@ -53,46 +55,43 @@ proc tclx_unknown2 cmd {
 
     if ![info exists auto_noexec] {
         if [auto_execok $name] {
-            if {!$tcl_interactive || [info level] > 1 || [info script] != ""} {
-                return -code error "Auto execution of Unix commands only supported as interactive commands.\nUse \"exec\" to execute \"$name\""
+            if {!$tcl_interactive || [info level] > 2 || [info script] != ""} {
+                return [list return -code error "Auto execution of Unix commands only supported as interactive commands.\nUse \"exec\" to execute \"$name\""]
             }
-            uplevel 1 system $cmd
-            return
+            return [list eval [list system $cmd] {;} concat]
         }
     }
 
+    if {!$tcl_interactive || ([info level] > 2) || [info script] != ""} {
+        return [list  return -code error "invalid command name \"$name\""]
+    }
+
     # csh-style redo.
 
-    if {$tcl_interactive && ([info level] == 1) && ([info script] == "") \
-	    && [info exists tcl_interactive] && $tcl_interactive} {
-	if ![info exists auto_noexec] {
-	    if [auto_execok $name] {
-		return [uplevel exec >&@stdout <@stdin $args]
-	    }
-	}
-	if {$name == "!!"} {
-	    return [uplevel {history redo}]
-	}
-	if [regexp {^!(.+)$} $name dummy event] {
-	    return [uplevel [list history redo $event]]
-	}
-	if [regexp {^\^([^^]*)\^([^^]*)\^?$} $name dummy old new] {
-	    return [uplevel [list history substitute $old $new]]
-	}
-	set cmds [info commands $name*]
-	if {[llength $cmds] == 1} {
-	    return [uplevel [lreplace $args 0 0 $cmds]]
-	}
-	if {[llength $cmds] != 0} {
-	    if {$name == ""} {
-		return -code error "empty command name \"\""
-	    } else {
-		return -code error \
-			"ambiguous command name \"$name\": [lsort $cmds]"
-	    }
-	}
+    if {([info level] == 2) && ([info script] == "")} {
+        if {$name == "!!"} {
+            return {history redo}
+        }
+        if [regexp {^!(.+)$} $name dummy event] {
+            return [list history redo $event]
+        }
+        if [regexp {^\^([^^]*)\^([^^]*)\^?$} $name dummy old new] {
+            return [list history substitute $old $new]
+        }
+        set cmds [info commands $name*]
+        if {[llength $cmds] == 1} {
+            return [lreplace $cmd 0 0 $cmds]
+        }
+        if {[llength $cmds] != 0} {
+            if {$name == ""} {
+                return [list return -code error "empty command name \"\""]
+            } else {
+                return [list return -code error \
+                        "ambiguous command name \"$name\": [lsort $cmds]"]
+            }
+        }
     }
-    return -code continue
+    return [list return -code error "invalid command name \"$name\""]
 }
 
 
