@@ -15,7 +15,7 @@
 # software for any purpose.  It is provided "as is" without express or
 # implied warranty.
 #------------------------------------------------------------------------------
-# $Id: instcopy.tcl,v 5.0 1995/07/25 05:59:31 markd Rel $
+# $Id: instcopy.tcl,v 5.1 1995/08/30 15:03:22 markd Exp $
 #------------------------------------------------------------------------------
 #
 # It is run in the following manner:
@@ -50,6 +50,9 @@ proc Usage {{msg {}}} {
 
 proc DoACopy {file target mode} {
 
+    if [cequal [file tail $file] "CVS"] {
+        return
+    }
     if {$mode == "FILENAME"} {
         set targetDir [file dirname $target]
         if [file exists $target] {
